@@ -704,6 +704,8 @@ class VirtualService(HttpClient, KempBaseObjectModel):
         self.real_servers = []
         self._waf = False
         self._waf_params = ['alertthreshold', 'intercept']
+        self._esp = False
+        self._esp_params = ['espenabled']
         if not is_sub_vs:
             # Skip validation when it is a subvs as they do not have ip/port
             self.vs = ip_or_index
@@ -745,6 +747,13 @@ class VirtualService(HttpClient, KempBaseObjectModel):
                     del api[entry]
                 except KeyError:
                     pass
+        if not self._esp:
+            for entry in self._esp_params:
+                # If it doesn't exist don't do anything
+                try:
+                    del api[entry]
+                except KeyError:
+                    pass
         return api
 
     def _get_base_parameters(self):
@@ -885,14 +894,20 @@ class VirtualService(HttpClient, KempBaseObjectModel):
         # WAF
         self.alertthreshold = service.get('AlertThreshold', None)
         self.intercept = service.get('Intercept', None)
+        # ESP
+        self.espenabled = service.get('EspEnabled', None)
         if self.alertthreshold is None or int(self.alertthreshold) == 0:
             self._waf = False
         else:
             self._waf = True
 
+        if self.espenabled is None or self.espenabled == 'N':
+            self._esp = False
+        else:
+            self._esp = True
+
         self.multiconnect = service.get('MultiConnect', None)
         self.verify = service.get('Verify', None)
-        self.espenabled = service.get('EspEnabled', None)
         self.compress = service.get('Compress', None)
         self.cache = service.get('Cache', None)
         self.cachepercent = service.get('CachePercent', None)
