@@ -167,7 +167,7 @@ class BackupFailed(KempTechApiException):
     def __init__(self, ip_address, code=None):
         msg = ("Failed to create a backup. Could not reach LoadMaster {}."
                .format(ip_address))
-        super(BackupFailed, self).__init__(msg, code=code)
+        super(BackupFailed, self).__init__(msg, code=code, is_xml_msg=False)
 
 
 class DownloadUserCertFailed(KempTechApiException):
